OC.L10N.register(
    "spreed",
    {
    "Guest" : "Gost",
    "None" : "Ništa",
    "User" : "User",
    "Name" : "naziv",
    "Off" : "Isključena",
    "Copy link" : "Kopiraj vezu",
    "Favorite" : "Omiljeni",
    "Leave conversation" : "Napusti razgovor",
    "Delete conversation" : "Obriši razgovor",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "Grupe",
    "Error" : "Greška",
    "Password protect" : "Zaštita lozinkom",
    "Back" : "Nazad",
    "Close" : "Zatvori",
    "Conversation name" : "Naziv razgovora",
    "Reply" : "Odgovori",
    "Today" : "Today",
    "Yesterday" : "juče",
    "Send message" : "Pošalji poruku",
    "guest" : "gost",
    "Demote from moderator" : "Skini ulogu moderatora",
    "Promote to moderator" : "Unapredi u moderatora",
    "Remove participant" : "Ukloni učesnika",
    "No results" : "Nema rezultata",
    "Participants" : "Učesnici",
    "Settings" : "Поставке",
    "Edit" : "Uredi",
    "Dismiss" : "Odbaci",
    "Rename conversation" : "Preimenuj razgovor",
    "Share link" : "Veza deljenja",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Grid view" : "Prikaz mreže",
    "Password" : "Password",
    "Copy" : "Kopiraj",
    "Copied!" : "Копирано!",
    "Not supported!" : "Није подржано!",
    "Press ⌘-C to copy." : "Притисни ⌘-C за копирање.",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за копирање.",
    "Password required" : "Potrebna je lozinka",
    "Cancel" : "Cancel",
    "Webinar" : "Vebinar",
    "Change password" : "Izmeni lozinku",
    "Set password" : "Postavi lozinku",
    "Rename" : "Rename",
    "Send" : "Pošalji",
    "Share" : "Deljenje",
    "Error while sharing" : "Greška pri deljenju"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
